/* Analysis of Gesture memorability study, second Experiment, recall analysis*/

GET DATA
  /TYPE=TXT
  /FILE="C:\GMAnalysis\Study2MainData_c2.csv"
  /DELCASE=LINE
  /DELIMITERS=","
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  User_ID A15
  Condition A11
  Order F1.0
  Application A10
  Stage A8
  Gesture A25
  Description A72
  DefAnswer F1.0
  Time_Spent F7.3
  GestureVideoSet A4.
CACHE.
EXECUTE.
DATASET NAME DataAll WINDOW=FRONT.

/* splitting the data for separate analysis of test 1 (reinforcement and test2 (next daty)
/* Note: definitiveAnswer is the good answer. 0 = correct, 1 = incorrect, 2 = execution error */

DATASET ACTIVATE DataAll.
DATASET COPY  Test1Raw.
DATASET ACTIVATE  Test1Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test1').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  Test2Raw.
DATASET ACTIVATE  Test2Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test2').
EXECUTE.
DATASET ACTIVATE  DataAll.

* Test1 Counts

DATASET ACTIVATE Test1Raw.
DATASET DECLARE Test1Counts.
AGGREGATE
  /OUTFILE='Test1Counts'
  /BREAK=User_ID Condition DefAnswer
  /N_BREAK=N.

* Graph of counts


DATASET ACTIVATE Test1Counts.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=DefAnswer MEANCI(N_BREAK, 
    95)[name="MEAN_N_BREAK" LOW="MEAN_N_BREAK_LOW" HIGH="MEAN_N_BREAK_HIGH"] Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: DefAnswer=col(source(s), name("DefAnswer"), unit.category())
  DATA: MEAN_N_BREAK=col(source(s), name("MEAN_N_BREAK"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_N_BREAK_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_N_BREAK_HIGH"))
  GUIDE: axis(dim(1), label("DefAnswer"))
  GUIDE: axis(dim(2), label("Mean N_BREAK"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Condition"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(DefAnswer*MEAN_N_BREAK), color.interior(Condition), missing.wings())    
  ELEMENT: interval(position(region.spread.range(DefAnswer*(LOW+HIGH))), 
    shape.interior(shape.ibeam), color.interior(Condition))
END GPL.

* Transform to Repeated measures format

DATASET ACTIVATE Test1Counts.
DATASET COPY Test1CountsRM.

DATASET ACTIVATE Test1CountsRM.
SORT CASES BY User_ID Condition DefAnswer.
CASESTOVARS
  /ID=User_ID
  /INDEX=Condition DefAnswer
  /GROUPBY=VARIABLE.

* Substitute empty values for 0's (conditions that had no cases)

DATASET ACTIVATE Test1CountsRM.
RECODE Predefined.0 Predefined.1 Predefined.2 Random.0 Random.1 Random.2 Selfdefined.0 
    Selfdefined.1 Selfdefined.2 (SYSMIS=0).
EXECUTE.

* Histograms test1 

DATASET ACTIVATE Test1Counts.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=N_BREAK DefAnswer Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: N_BREAK=col(source(s), name("N_BREAK"))
  DATA: DefAnswer=col(source(s), name("DefAnswer"), unit.category())
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  GUIDE: axis(dim(1), label("N_BREAK"))
  GUIDE: axis(dim(2), label("Frequency"))
  GUIDE: axis(dim(3), label("DefAnswer"), opposite())
  GUIDE: axis(dim(4), label("Condition"), opposite())
  ELEMENT: interval(position(summary.count(bin.rect(N_BREAK*1*DefAnswer*Condition))), 
    shape.interior(shape.square))
  ELEMENT: line(position(density.normal(N_BREAK*1*DefAnswer*Condition)), color("Normal"))
END GPL.

* Omnibus analysis of Test1 (reinforcement) and post-hocs

DATASET ACTIVATE Test1CountsRM.
GLM Predefined.0 Random.0 Selfdefined.0
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

* Test2 Counts

DATASET ACTIVATE Test2Raw.
DATASET DECLARE Test2Counts.
AGGREGATE
  /OUTFILE='Test2Counts'
  /BREAK=User_ID Condition DefAnswer
  /N_BREAK=N.

/* Graph of counts (Next day test) */


DATASET ACTIVATE Test2Counts.

* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=DefAnswer MEANCI(N_BREAK, 
    95)[name="MEAN_N_BREAK" LOW="MEAN_N_BREAK_LOW" HIGH="MEAN_N_BREAK_HIGH"] Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: DefAnswer=col(source(s), name("DefAnswer"), unit.category())
  DATA: MEAN_N_BREAK=col(source(s), name("MEAN_N_BREAK"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_N_BREAK_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_N_BREAK_HIGH"))
  GUIDE: axis(dim(1), label("DefAnswer"))
  GUIDE: axis(dim(2), label("Mean N_BREAK"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Condition"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(DefAnswer*MEAN_N_BREAK), color.interior(Condition), missing.wings())    
  ELEMENT: interval(position(region.spread.range(DefAnswer*(LOW+HIGH))), 
    shape.interior(shape.ibeam), color.interior(Condition))
END GPL.

* Transform to RM format

DATASET ACTIVATE Test2Counts.
DATASET COPY Test2CountsRM.

DATASET ACTIVATE Test2CountsRM.
SORT CASES BY User_ID Condition DefAnswer.
CASESTOVARS
  /ID=User_ID
  /INDEX=Condition DefAnswer
  /GROUPBY=VARIABLE.

* Missing values = 0

DATASET ACTIVATE Test2CountsRM.
RECODE Predefined.0 Predefined.1 Predefined.2 Random.0 Random.1 Random.2 Selfdefined.0 
    Selfdefined.1 Selfdefined.2 (SYSMIS=0).
EXECUTE.

* Histogram test 2 

DATASET ACTIVATE Test2Counts.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=N_BREAK DefAnswer Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: N_BREAK=col(source(s), name("N_BREAK"))
  DATA: DefAnswer=col(source(s), name("DefAnswer"), unit.category())
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  GUIDE: axis(dim(1), label("N_BREAK"))
  GUIDE: axis(dim(2), label("Frequency"))
  GUIDE: axis(dim(3), label("DefAnswer"), opposite())
  GUIDE: axis(dim(4), label("Condition"), opposite())
  ELEMENT: interval(position(summary.count(bin.rect(N_BREAK*1*DefAnswer*Condition))), 
    shape.interior(shape.square))
  ELEMENT: line(position(density.normal(N_BREAK*1*DefAnswer*Condition)), color("Normal"))
END GPL.

* Omnibus analysis of Test2 (reinforcement) and post-hocs

DATASET ACTIVATE Test2CountsRM.
GLM Predefined.0 Random.0 Selfdefined.0
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=ETASQ OPOWER
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

/* analysis of type of errors  1 is error in association of gesture, 2 is error of partial gesture*/

* Omnibus

DATASET ACTIVATE Test2CountsRM.
GLM Predefined.1 Predefined.2 Random.1 Random.2 Selfdefined.1 Selfdefined.2
  /WSFACTOR=gestureSet 3 Polynomial typeOfError 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet gestureSet*typeOfError typeOfError*gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(typeOfError) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet typeOfError gestureSet*typeOfError.

* Only for execution errors

GLM Predefined.2 Random.2 Selfdefined.2
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

* Only for association errors


GLM Predefined.1 Random.1 Selfdefined.1
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

