/* Analysis of Gesture memorability study, second Experiment - time analysis*/

GET DATA
  /TYPE=TXT
  /FILE="C:\GMAnalysis\Study2MainData_c2.csv"
  /DELCASE=LINE
  /DELIMITERS=","
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  User_ID A15
  Condition A11
  Order F1.0
  Application A10
  Stage A8
  Gesture A25
  Description A72
  DefAnswer F1.0
  Time_Spent F7.3
  GestureVideoSet A4.
CACHE.
EXECUTE.
DATASET NAME DataAll WINDOW=FRONT.

* first we compute the logarithm of the times

DATASET ACTIVATE DataAll.
COMPUTE logtime_spent=LG10(time_spent).
EXECUTE.

/* splitting the data for separate analysis of test 1 (reinforcement and test2 (next daty)
/* Note: definitiveAnswer is the good answer. 0 = correct, 1 = incorrect, 2 = execution error */

DATASET ACTIVATE DataAll.
DATASET COPY  Test1Raw.
DATASET ACTIVATE  Test1Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test1').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  Test2Raw.
DATASET ACTIVATE  Test2Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test2').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  TrainingRaw.
DATASET ACTIVATE  TrainingRaw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Training').
EXECUTE.
DATASET ACTIVATE  DataAll.

* Fixing the difference in logging for training
* Sum the times for the repetitions in the training (each repetition was logged separately)

DATASET ACTIVATE TrainingRaw.
DATASET DECLARE TrainingRawFixed.
AGGREGATE
  /OUTFILE='TrainingRawFixed'
  /BREAK=User_ID Condition Order Application Stage Gesture Description
  /Time_Spent_sum=SUM(Time_Spent).

* recalculate the log times

DATASET ACTIVATE TrainingRawFixed.
COMPUTE logtime_spent=LG10(Time_Spent_sum).
EXECUTE.

/* Training times analysis */

* Aggregate measures 

DATASET ACTIVATE TrainingRawFixed.
DATASET DECLARE AggregatedLogTimesTraining.
AGGREGATE
  /OUTFILE='AggregatedLogTimesTraining'
  /BREAK=User_ID Condition
  /logtime_spent_mean=MEAN(logtime_spent).

* Plot time spent (logtransformed)

DATASET ACTIVATE AggregatedLogTimesTraining.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition MEANCI(logtime_spent_mean, 
    95)[name="MEAN_logtime_spent_mean" LOW="MEAN_logtime_spent_mean_LOW" 
    HIGH="MEAN_logtime_spent_mean_HIGH"] MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_spent_mean=col(source(s), name("MEAN_logtime_spent_mean"))
  DATA: LOW=col(source(s), name("MEAN_logtime_spent_mean_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_logtime_spent_mean_HIGH"))
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_spent_mean"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_spent_mean), missing.wings())
  ELEMENT: interval(position(region.spread.range(Condition*(LOW+HIGH))), 
    shape.interior(shape.ibeam))
END GPL.

* times spent depending on participant

DATASET ACTIVATE AggregatedLogTimesTraining.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition 
    MEAN(logtime_spent_mean)[name="MEAN_logtime_spent_mean"] User_ID MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_spent_mean=col(source(s), name("MEAN_logtime_spent_mean"))
  DATA: User_ID=col(source(s), name("User_ID"), unit.category())
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_spent_mean"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("User_ID"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_spent_mean), color.interior(User_ID), 
    missing.wings())
END GPL.

* Convert file to Repeated Measures Format

DATASET ACTIVATE AggregatedLogTimesTraining.
DATASET COPY AggregatedLogTimesTrainingRM.

DATASET ACTIVATE AggregatedLogTimesTrainingRM.

SORT CASES BY User_ID Condition.
CASESTOVARS
  /ID=User_ID
  /INDEX=Condition
  /GROUPBY=VARIABLE.

* ANOVA of duration times (log transformed) with post-hocs

DATASET ACTIVATE AggregatedLogTimesTrainingRM.

GLM Predefined Random Selfdefined
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

/* Analysis of the tests next day (test2) - RESPONSE TIMES  */

DATASET ACTIVATE Test2Raw.
DATASET DECLARE test2TimesAggregated.
AGGREGATE
  /OUTFILE='test2TimesAggregated'
  /BREAK=User_ID Condition
  /logtime_spent_mean=MEAN(logtime_spent).

* Graphs times2

DATASET ACTIVATE test2TimesAggregated.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition MEANCI(logtime_spent_mean, 
    95)[name="MEAN_logtime_spent_mean" LOW="MEAN_logtime_spent_mean_LOW" 
    HIGH="MEAN_logtime_spent_mean_HIGH"] MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_spent_mean=col(source(s), name("MEAN_logtime_spent_mean"))
  DATA: LOW=col(source(s), name("MEAN_logtime_spent_mean_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_logtime_spent_mean_HIGH"))
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_spent_mean"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_spent_mean), missing.wings())
  ELEMENT: interval(position(region.spread.range(Condition*(LOW+HIGH))), 
    shape.interior(shape.ibeam))
END GPL.

* ANOVAS time test2 (next day)

* transform to repeated measures format

DATASET ACTIVATE  test2TimesAggregated.
DATASET COPY  test2TimesAggregatedRM.
DATASET ACTIVATE  test2TimesAggregatedRM.
SORT CASES BY User_ID Condition.
CASESTOVARS
  /ID=User_ID
  /INDEX=Condition
  /GROUPBY=VARIABLE.

DATASET ACTIVATE test2TimesAggregatedRM.
GLM Predefined Random Selfdefined
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.




