/* Analysis of Gesture memorability study, third Experiment*/

* Open file

GET DATA
  /TYPE=TXT
  /FILE="C:\GMAnalysis\Study3MainData_c2.csv"
  /DELCASE=LINE
  /DELIMITERS=","
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  UserId A5
  Condition A11
  ConditionOrder F1.0
  Stage A8
  Application A8
  GestureName A25
  GestureNumber F2.0
  GestureTestNumber F2.0
  GestureReinforced A5
  Answer F1.0
  time_spent F7.3
  time_answer F7.3
  GestureDescription A71
  VideoShownToUserFilename A92
  GestureVideoSet A62.
CACHE.
EXECUTE.
DATASET NAME DataAll WINDOW=FRONT.

/* splitting the data for separate analysis of test 1 (reinforcement) and test 2 (next day) */
/* Note: Answer is the good answer. 0 = correct, 1 = incorrect, 2 = close (execution error) */

DATASET ACTIVATE DataAll.
DATASET COPY  Test1Raw.
DATASET ACTIVATE  Test1Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test1').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  Test2Raw.
DATASET ACTIVATE  Test2Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test2').
EXECUTE.
DATASET ACTIVATE  DataAll.

* Test1 Counts

DATASET ACTIVATE Test1Raw.
DATASET DECLARE Test1Counts.
AGGREGATE
  /OUTFILE='Test1Counts'
  /BREAK=UserId Condition Answer
  /N_BREAK=N.

/* Graph of counts */

DATASET ACTIVATE Test1Counts.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Answer MEANCI(N_BREAK, 95)[name="MEAN_N_BREAK" 
    LOW="MEAN_N_BREAK_LOW" HIGH="MEAN_N_BREAK_HIGH"] Condition MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: MEAN_N_BREAK=col(source(s), name("MEAN_N_BREAK"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_N_BREAK_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_N_BREAK_HIGH"))
  GUIDE: axis(dim(1), label("Answer"))
  GUIDE: axis(dim(2), label("Mean N_BREAK"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Condition"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Answer*MEAN_N_BREAK), color.interior(Condition), missing.wings())
  ELEMENT: interval(position(region.spread.range(Answer*(LOW+HIGH))), 
    shape.interior(shape.ibeam), color.interior(Condition))
END GPL.

DATASET ACTIVATE Test1Counts.
DATASET COPY Test1CountsRM.

* Transform to Repeated Measures format

DATASET ACTIVATE Test1CountsRM.
SORT CASES BY UserId Condition Answer.
CASESTOVARS
  /ID=UserId
  /INDEX=Condition Answer
  /GROUPBY=VARIABLE.

* Substitute empty values for 0's (conditions that had no cases)

DATASET ACTIVATE Test1CountsRM.
RECODE Predesigned.0 Predesigned.1 Predesigned.2 Random.0 Random.1 Random.2 Selfdefined.0 
    Selfdefined.1 Selfdefined.2 (SYSMIS=0).
EXECUTE.

* Histograms Test1

DATASET ACTIVATE Test1Counts.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=N_BREAK Answer Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: N_BREAK=col(source(s), name("N_BREAK"))
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  GUIDE: axis(dim(1), label("N_BREAK"))
  GUIDE: axis(dim(2), label("Frequency"))
  GUIDE: axis(dim(3), label("Answer"), opposite())
  GUIDE: axis(dim(4), label("Condition"), opposite())
  ELEMENT: interval(position(summary.count(bin.rect(N_BREAK*1*Answer*Condition))), 
    shape.interior(shape.square))
END GPL.

* Omnibus analysis of Test1 (reinforcement) and post-hocs

DATASET ACTIVATE Test1CountsRM.
GLM Predesigned.0 Random.0 Selfdefined.0
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

* Test2 Counts

DATASET ACTIVATE Test2Raw.
DATASET DECLARE Test2Counts.
AGGREGATE
  /OUTFILE='Test2Counts'
  /BREAK=UserId Condition Answer
  /N_BREAK=N.

/* Graph of counts */

DATASET ACTIVATE Test2Counts.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Answer MEANCI(N_BREAK, 95)[name="MEAN_N_BREAK" 
    LOW="MEAN_N_BREAK_LOW" HIGH="MEAN_N_BREAK_HIGH"] Condition MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: MEAN_N_BREAK=col(source(s), name("MEAN_N_BREAK"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_N_BREAK_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_N_BREAK_HIGH"))
  GUIDE: axis(dim(1), label("Answer"))
  GUIDE: axis(dim(2), label("Mean N_BREAK"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Condition"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Answer*MEAN_N_BREAK), color.interior(Condition), missing.wings())
  ELEMENT: interval(position(region.spread.range(Answer*(LOW+HIGH))), 
    shape.interior(shape.ibeam), color.interior(Condition))
END GPL.

* Transform to RM format

DATASET ACTIVATE Test2Counts.
DATASET COPY Test2CountsRM.

DATASET ACTIVATE Test2CountsRM.
SORT CASES BY UserId Condition Answer.
CASESTOVARS
  /ID=UserId
  /INDEX=Condition Answer
  /GROUPBY=VARIABLE.

* Missing values = 0

DATASET ACTIVATE Test2CountsRM.
RECODE Predesigned.0 Predesigned.1 Predesigned.2 Random.0 Random.1 Random.2 Selfdefined.0 
    Selfdefined.1 Selfdefined.2 (SYSMIS=0).
EXECUTE.

* Histograms Test2

DATASET ACTIVATE Test2Counts.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=N_BREAK Answer Condition MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: N_BREAK=col(source(s), name("N_BREAK"))
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  GUIDE: axis(dim(1), label("N_BREAK"))
  GUIDE: axis(dim(2), label("Frequency"))
  GUIDE: axis(dim(3), label("Answer"), opposite())
  GUIDE: axis(dim(4), label("Condition"), opposite())
  ELEMENT: interval(position(summary.count(bin.rect(N_BREAK*1*Answer*Condition))), 
    shape.interior(shape.square))
END GPL.

* Omnibus analysis of Test2 (reinforcement) and post-hocs

DATASET ACTIVATE Test2CountsRM.
GLM Predesigned.0 Random.0 Selfdefined.0
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=ETASQ OPOWER
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

* Analysis of test2 separating reinforced and not reinforced

DATASET ACTIVATE Test2Raw.
DATASET DECLARE Test2CountsReinforcedAndNot.
AGGREGATE
  /OUTFILE='Test2CountsReinforcedAndNot'
  /BREAK=UserId Condition Answer GestureReinforced
  /N_BREAK=N.

* lines GRAPH test2 separating by reinforced and not

DATASET ACTIVATE Test2CountsReinforcedAndNot.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Answer MEANCI(N_BREAK, 95)[name="MEAN_N_BREAK" 
    LOW="MEAN_N_BREAK_LOW" HIGH="MEAN_N_BREAK_HIGH"] Condition GestureReinforced MISSING=LISTWISE 
    REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: MEAN_N_BREAK=col(source(s), name("MEAN_N_BREAK"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: GestureReinforced=col(source(s), name("GestureReinforced"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_N_BREAK_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_N_BREAK_HIGH"))
  GUIDE: axis(dim(1), label("Answer"))
  GUIDE: axis(dim(2), label("Mean N_BREAK"))
  GUIDE: axis(dim(3), label("GestureReinforced"), opposite())
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("Condition"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Answer*MEAN_N_BREAK*GestureReinforced), color.interior(Condition), 
    missing.wings())
  ELEMENT: interval(position(region.spread.range(Answer*(LOW+HIGH)*GestureReinforced)), 
    shape.interior(shape.ibeam), color.interior(Condition))
END GPL.


* Histograms stacking reinforced and non-reinforced

GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=N_BREAK GestureReinforced Answer Condition 
    MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: N_BREAK=col(source(s), name("N_BREAK"))
  DATA: GestureReinforced=col(source(s), name("GestureReinforced"), unit.category())
  DATA: Answer=col(source(s), name("Answer"), unit.category())
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  GUIDE: axis(dim(1), label("N_BREAK"))
  GUIDE: axis(dim(2), label("Frequency"))
  GUIDE: axis(dim(3), label("Answer"), opposite())
  GUIDE: axis(dim(4), label("Condition"), opposite())
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("GestureReinforced"))
  ELEMENT: interval.stack(position(summary.count(bin.rect(N_BREAK*1*Answer*Condition))), 
    color.interior(GestureReinforced), shape.interior(shape.square))
END GPL.

* Transform to Repeated Measures format

SORT CASES BY UserId Condition Answer GestureReinforced.
CASESTOVARS
  /ID=UserId
  /INDEX=Condition Answer GestureReinforced
  /GROUPBY=VARIABLE.

* Missing values = 0

RECODE Predesigned.0.False Predesigned.0.True Predesigned.1.False Predesigned.1.True 
    Predesigned.2.False Predesigned.2.True Random.0.False Random.0.True Random.1.False Random.1.True 
    Random.2.False Random.2.True Selfdefined.0.False Selfdefined.0.True Selfdefined.1.False 
    Selfdefined.1.True Selfdefined.2.False Selfdefined.2.True (SYSMIS=0).
EXECUTE.

* Omnibus RM analysis (3 conditions, 2 reinforced) for next-day tests (test2) 

GLM Predesigned.0.False Predesigned.0.True Random.0.False Random.0.True Selfdefined.0.False 
    Selfdefined.0.True
  /WSFACTOR=Conditions 3 Polynomial reinforcement 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(Conditions Conditions*reinforcement)
  /EMMEANS=TABLES(Conditions) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(reinforcement) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(Conditions*reinforcement) 
  /PRINT=ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=Conditions reinforcement Conditions*reinforcement.

/* analysis of type of errors  1 is error in association of gesture, 2 is error of partial gesture*/

* Omnibus

DATASET ACTIVATE Test2CountsRM.
GLM Predesigned.1 Predesigned.2 Random.1 Random.2 Selfdefined.1 Selfdefined.2
  /WSFACTOR=gestureSet 3 Polynomial typeOfError 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet gestureSet*typeOfError typeOfError*gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(typeOfError) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet typeOfError gestureSet*typeOfError.

* Only for execution errors

GLM Predesigned.2 Random.2 Selfdefined.2
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

* Only for association errors


GLM Predesigned.1 Random.1 Selfdefined.1
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.



