/* Analysis of Gesture memorability study, third Experiment, times analysis */

* Open file

GET DATA
  /TYPE=TXT
  /FILE="C:\GMAnalysis\Study3MainData_c2.csv"
  /DELCASE=LINE
  /DELIMITERS=","
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  UserId A5
  Condition A11
  ConditionOrder F1.0
  Stage A8
  Application A8
  GestureName A25
  GestureNumber F2.0
  GestureTestNumber F2.0
  GestureReinforced A5
  Answer F1.0
  time_spent F7.3
  time_answer F7.3
  GestureDescription A71
  VideoShownToUserFilename A92
  GestureVideoSet A62.
CACHE.
EXECUTE.
DATASET NAME DataAll WINDOW=FRONT.

* Eliminate the demo recordings (these are the ones where the experimenter showed the participant with three examples how the system works

DATASET ACTIVATE DataAll.
FILTER OFF.
USE ALL.
SELECT IF (Condition ~= 'Training').
EXECUTE.


* Calculate the logarithmic (Lg10) of the time spent (learning and creating gestures) variable

DATASET ACTIVATE DataAll.
COMPUTE logtime_spent=LG10(time_spent).
EXECUTE.

* Calculate the logarithmic (Lg10) of the time until answer variable

DATASET ACTIVATE DataAll.
COMPUTE logtime_answer=LG10(time_answer).
EXECUTE.

/* splitting the data for separate analysis of training,  test 1 (reinforcement) and test 2 (next day) */
/* Note: MFirstAnswer is the good answer. 0 = correct, 1 = incorrect, 2 = close (execution error) */

DATASET ACTIVATE DataAll.
DATASET COPY  TrainingRaw.
DATASET ACTIVATE  TrainingRaw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Training').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  Test1Raw.
DATASET ACTIVATE  Test1Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test1').
EXECUTE.
DATASET ACTIVATE  DataAll.

DATASET ACTIVATE DataAll.
DATASET COPY  Test2Raw.
DATASET ACTIVATE  Test2Raw.
FILTER OFF.
USE ALL.
SELECT IF (Stage = 'Test2').
EXECUTE.
DATASET ACTIVATE  DataAll.

/* Training times analysis */

* Aggregate measures 

DATASET ACTIVATE TrainingRaw.
DATASET DECLARE AggregatedLogTimesTraining.
AGGREGATE
  /OUTFILE='AggregatedLogTimesTraining'
  /BREAK=UserId Condition
  /logtime_spent_mean=MEAN(logtime_spent).

* Plot time spent (logtransformed)

DATASET ACTIVATE AggregatedLogTimesTraining.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition MEANCI(logtime_spent_mean, 
    95)[name="MEAN_logtime_spent_mean" LOW="MEAN_logtime_spent_mean_LOW" 
    HIGH="MEAN_logtime_spent_mean_HIGH"] MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_spent_mean=col(source(s), name("MEAN_logtime_spent_mean"))
  DATA: LOW=col(source(s), name("MEAN_logtime_spent_mean_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_logtime_spent_mean_HIGH"))
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_spent_mean"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_spent_mean), missing.wings())
  ELEMENT: interval(position(region.spread.range(Condition*(LOW+HIGH))), 
    shape.interior(shape.ibeam))
END GPL.

* The following graph shows times spent depending on participant

DATASET ACTIVATE TrainingRaw.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition 
    MEAN(logtime_spent)[name="MEAN_logtime_spent"] UserId MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_spent=col(source(s), name("MEAN_logtime_spent"))
  DATA: UserId=col(source(s), name("UserId"), unit.category())
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_spent"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("UserId"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_spent), color.interior(UserId), missing.wings())
END GPL.

* Convert file to Repeated Measures Format

DATASET ACTIVATE AggregatedLogTimesTraining.
DATASET COPY AggregatedLogTimesTrainingRM.

DATASET ACTIVATE AggregatedLogTimesTrainingRM.

SORT CASES BY UserId Condition.
CASESTOVARS
  /ID=UserId
  /INDEX=Condition
  /GROUPBY=VARIABLE.

* ANOVA of duration times (log transformed) with post-hocs

DATASET ACTIVATE AggregatedLogTimesTrainingRM.

GLM Predesigned Random Selfdefined
  /WSFACTOR=gestureSet 3 Polynomial 
  /METHOD=SSTYPE(3)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet.

/* Analysis of the tests next day (test2) - RESPONSE TIMES  */

DATASET ACTIVATE Test2Raw.
DATASET DECLARE test2_time_answer_aggregated_reinfandnot.
AGGREGATE
  /OUTFILE='test2_time_answer_aggregated_reinfandnot'
  /BREAK=UserId Condition GestureReinforced
  /time_answer_mean=MEAN(time_answer) 
  /logtime_answer_mean=MEAN(logtime_answer).

* graphs time2 

DATASET ACTIVATE test2_time_answer_aggregated_reinfandnot.
* Chart Builder.
GGRAPH
  /GRAPHDATASET NAME="graphdataset" VARIABLES=Condition MEANCI(logtime_answer_mean, 
    95)[name="MEAN_logtime_answer_mean" LOW="MEAN_logtime_answer_mean_LOW" 
    HIGH="MEAN_logtime_answer_mean_HIGH"] GestureReinforced MISSING=LISTWISE REPORTMISSING=NO
  /GRAPHSPEC SOURCE=INLINE.
BEGIN GPL
  SOURCE: s=userSource(id("graphdataset"))
  DATA: Condition=col(source(s), name("Condition"), unit.category())
  DATA: MEAN_logtime_answer_mean=col(source(s), name("MEAN_logtime_answer_mean"))
  DATA: GestureReinforced=col(source(s), name("GestureReinforced"), unit.category())
  DATA: LOW=col(source(s), name("MEAN_logtime_answer_mean_LOW"))
  DATA: HIGH=col(source(s), name("MEAN_logtime_answer_mean_HIGH"))
  GUIDE: axis(dim(1), label("Condition"))
  GUIDE: axis(dim(2), label("Mean logtime_answer_mean"))
  GUIDE: legend(aesthetic(aesthetic.color.interior), label("GestureReinforced"))
  GUIDE: text.footnote(label("Error Bars: 95% CI"))
  SCALE: linear(dim(2), include(0))
  ELEMENT: line(position(Condition*MEAN_logtime_answer_mean), color.interior(GestureReinforced), 
    missing.wings())
  ELEMENT: interval(position(region.spread.range(Condition*(LOW+HIGH))), 
    shape.interior(shape.ibeam), color.interior(GestureReinforced))
END GPL.

* ANOVAS time test2 (next day)

* transform to repeated measures format - Reinforced = 2, non-reinforced = 1.

DATASET ACTIVATE test2_time_answer_aggregated_reinfandnot.
DATASET COPY test2_time_answer_aggregated_reinfandnot_RM.
DATASET ACTIVATE test2_time_answer_aggregated_reinfandnot_RM.
SORT CASES BY UserId Condition GestureReinforced.
CASESTOVARS
  /ID=UserId
  /INDEX=Condition GestureReinforced
  /GROUPBY=VARIABLE.

DATASET ACTIVATE test2_time_answer_aggregated_reinfandnot_RM.
GLM logtime_answer_mean.Predesigned.False logtime_answer_mean.Predesigned.True 
    logtime_answer_mean.Random.False logtime_answer_mean.Random.True logtime_answer_mean.Selfdefined.False 
    logtime_answer_mean.Selfdefined.True
  /WSFACTOR=gestureSet 3 Polynomial reinforced 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PLOT=PROFILE(gestureSet gestureSet*reinforced)
  /EMMEANS=TABLES(gestureSet) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(reinforced) COMPARE ADJ(LSD)
  /EMMEANS=TABLES(gestureSet*reinforced) 
  /PRINT=DESCRIPTIVE ETASQ OPOWER 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=gestureSet reinforced gestureSet*reinforced.

